summaryrefslogtreecommitdiff
path: root/plugins/pythonconsole/pythonconsole/config.py
diff options
context:
space:
mode:
authorPerberos <[email protected]>2011-11-07 19:52:18 -0300
committerPerberos <[email protected]>2011-11-07 19:52:18 -0300
commit5ded9cba8563f336939400303d6a841d5089b107 (patch)
treec5676588cff26ba37e12369fe4de24b54e9f6682 /plugins/pythonconsole/pythonconsole/config.py
parentf00b3a11a199f9f85a4d46a600f9d14179b37dbf (diff)
downloadpluma-5ded9cba8563f336939400303d6a841d5089b107.tar.bz2
pluma-5ded9cba8563f336939400303d6a841d5089b107.tar.xz
renaming from gedit to pluma
Diffstat (limited to 'plugins/pythonconsole/pythonconsole/config.py')
-rwxr-xr-xplugins/pythonconsole/pythonconsole/config.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/plugins/pythonconsole/pythonconsole/config.py b/plugins/pythonconsole/pythonconsole/config.py
index fed4699b..ac0e599c 100755
--- a/plugins/pythonconsole/pythonconsole/config.py
+++ b/plugins/pythonconsole/pythonconsole/config.py
@@ -21,7 +21,7 @@
# Parts from "Interactive Python-GTK Console" (stolen from epiphany's console.py)
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
# Bits from gedit Python Console Plugin
# Copyrignt (C), 2005 Raphaƫl Slinckx
import os
@@ -29,7 +29,7 @@ import gtk
__all__ = ('PythonConsoleConfig', 'PythonConsoleConfigDialog')
-MATECONF_KEY_BASE = '/apps/gedit-2/plugins/pythonconsole'
+MATECONF_KEY_BASE = '/apps/pluma-2/plugins/pythonconsole'
MATECONF_KEY_COMMAND_COLOR = MATECONF_KEY_BASE + '/command-color'
MATECONF_KEY_ERROR_COLOR = MATECONF_KEY_BASE + '/error-color'
@@ -21,7 +21,7 @@
# Copyright (C), 1998 James Henstridge <[email protected]>
# Copyright (C), 2005 Adam Hooper <[email protected]>
-# Bits from gedit Python Console Plugin
+# Bits from pluma Python Console Plugin
# Copyrignt (C), 2005 Raphaƫl Slinckx
import os